/* -*-C-*- unixlib.h */
/*-->unixlib*/
/**********************************************************************/
/******************************* unixlib ******************************/
/**********************************************************************/

#ifdef _AIX
	/* IBM AIX (PS/2 and mainframe) defines these functions */
	/* and raises errors if they are redeclared */
#define UNIXLIB_H_DEFINED__
#endif

#ifdef __sgi
#include <unistd.h>			/* get system call declarations */
#define UNIXLIB_H_DEFINED__
#endif

#ifndef UNIXLIB_H_DEFINED__
#define UNIXLIB_H_DEFINED__

/***********************************************************************

This  file provides function prototypes  for UNIX library functions that
are  usually not declared in  <stdio.h> or  other  commonly-used include
files.  Few UNIX systems yet have ANSI draft  C conformant compilers and
libraries,  but GNU gcc  offers at least  the compiler  part   (no GNU C
library is yet available; the  host C  library is  used instead), and it
can be  asked to check argument passing   and identify functions lacking
prototype declarations.

This file requires definitions of  fpos_t and size_t; both are  provided
by "os.h", which should be  included before this file.

***********************************************************************/

#ifndef OS_H_DEFINED__
#include "os.h"
#endif /* OS_H_DEFINED__ */

#if    OS_UNIX

#include "xstat.h"

#ifdef sun
				/* <stdio.h> uses these without prototypes */
int		_filbuf ARGS((FILE *fp));
int		_flsbuf ARGS((unsigned char  c, FILE *fp));
#endif /* sun */

/* Low-level I/O functions */

int		access ARGS((const char *file_spec, int mode));

#ifndef HAVE_CLOSE_DCL
int		close ARGS((int file_desc));
#endif

#ifndef HAVE_CREAT_DCL
int		creat ARGS((char *file_spec, unsigned int mode, ...));
#endif

int		delete ARGS((const char *file_spec));
int		dup ARGS((int file_desc));
int		dup2 ARGS((int fd_1, int fd_2));
int		fstat ARGS((int file_desc, struct stat *buffer));
char		*getname ARGS((int file_desc, char *buffer, ...));
int		ioctl ARGS((int file_desc, int request, ...));
int		isapipe ARGS((int file_desc));
int		isatty ARGS((int file_desc));
int		lseek ARGS((int file_desc, int offset, int direction));
char		*mktemp ARGS((char *template));

#ifndef HAVE_OPEN_DCL
int		open ARGS((char *file_spec, int flags, ...));
#endif

int		read ARGS((int file_desc, void *buffer, size_t nbytes));
int		remove ARGS((const char *file_spec));
int		rename ARGS((const char *old_file_spec,
			const char *new_file_spec));
int		stat ARGS((const char *file_spec, struct stat *buffer));
char		*ttyname ARGS((void));
int		write ARGS((int file_desc, void *buffer, size_t nbytes));

/* High-level I/O functions.  It appears that library functions of type
int usually are not given prototypes in UNIX stdio.h. */

int		fclose ARGS((FILE *file_ptr));
int		fflush ARGS((FILE *file_ptr));
int		fgetc ARGS((FILE *file_ptr));
int		fgetpos ARGS((FILE *file_ptr, fpos_t *position));
int		fprintf ARGS((FILE *file_ptr, const char *format_spec, ...));
int		fputc ARGS((int character, FILE *file_ptr));
int		fputs ARGS((const char *str, FILE *file_ptr));
int		fscanf ARGS((FILE *file_ptr, const char *format_spec, ...));
int		fseek ARGS((FILE *file_ptr, long offset, int direction));
int		fsetpos ARGS((FILE *file_ptr, const fpos_t *position));
long		ftell ARGS((FILE *file_ptr));
int		getw ARGS((FILE *file_ptr));
int		printf ARGS((const char *format_spec, ...));
int		puts ARGS((const char *str));
int		putw ARGS((int integer, FILE *file_ptr));
void		rewind ARGS((FILE *file_ptr));
int		scanf ARGS((const char *format_spec, ...));

#ifndef ardent
int		setvbuf ARGS((FILE *file_ptr, char *buffer, int type,
			size_t size));
#endif /* ardent */

#ifndef HAVE_SPRINTF_DCL
#ifdef ultrix
char		*sprintf ARGS((char *str, const char *format_spec, ...));
#else /* NOT ultrix */
#ifdef apollo
char		*sprintf ARGS((char *str, char *format_spec, ...));
#else /* NOT apollo */
#ifdef sun
char		*sprintf ARGS((char *str, const char *format_spec, ...));
#else
int		sprintf ARGS((char *str, const char *format_spec, ...));
#endif /* sun */
#endif /* apollo */
#endif /* ultrix */
#endif /* HAVE_SPRINTF_DCL */

int		sscanf ARGS((const char *str, const char *format_spec, ...));
int		ungetc ARGS((int character, FILE *file_ptr));

/* miscellaneous library functions */

void		bzero ARGS((char  *s, int n));
void		perror ARGS((const char  *s));
unsigned int	sleep ARGS((unsigned int seconds));
int		system ARGS((const char  *command));
int		tell ARGS((int file_desc));
				/* obsolete; use lseek(file_desc,0L,1) */
time_t		time ARGS((time_t *time_location));
int		unlink ARGS((const char  *path));
unsigned int	usleep ARGS((unsigned int microseconds)); /* in Sun OS */
#endif /* OS_UNIX */
#endif /* UNIXLIB_H_DEFINED__ */
